@@ -84,6 +84,10 @@ GCONF_EXPAND = GCONF_DIR + "/expand"
 
 # GConf key to the setting for the minimum number of chars of a query
 GCONF_MINCHARS = GCONF_DIR + "/minchars"
+# GConf key to the setting for time between keystroke in search entry, and actual search
+GCONF_TYPINGDELAY = GCONF_DIR + "/typingdelay"
+# GConf key to the setting whether to use selection clipboard when activating hotkey
+GCONF_USE_SELECTION = GCONF_DIR + "/use_selection"
 # GConf key for global keybinding
 GCONF_KEYBINDING = GCONF_DIR + "/keybinding"
 
@@ -92,6 +96,7 @@ GCONF_UI_NAME = GCONF_DIR + "/ui_name"
 
 ENTRIAC_UI_NAME = "Entriac"
 CUEMIAC_UI_NAME = "Cuemiac"
+WINDOW_UI_NAME = "Window"
 
 # GConf key for list of enabled handlers, when uninstalled, use a debug key to not conflict
 # with development version
